package dsekercioglu.mega.megaCore;

import static dsekercioglu.mega.megaCore.KNNPredictor.DistanceFunction.EUCLIDEAN;
import static dsekercioglu.mega.megaCore.KNNPredictor.DistanceFunction.MANHATTAN;
import static dsekercioglu.mega.megaCore.KNNPredictor.DistanceFunction.SQR_EUCLIDEAN;
import dsekercioglu.mega.megaCore.jk.kdTree.KDTree;
import dsekercioglu.mega.megaCore.jk.kdTree.KDTree.SearchResult;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.ListIterator;

public class KNNPredictor extends CorePredictor {

    public KDTree predictor;
    private int BINS;
    private int K;
    private double[] WEIGHTS;
    private double MAX_DISTANCE;
    private KDeterminationAlgorithm ALGORITHM;

    boolean takeSquareroot = false;

    public void setup(double[] weights, int k, int bins, DistanceFunction distanceFunction, KDeterminationAlgorithm algorithm) {
        switch (distanceFunction) {
            case EUCLIDEAN:
                predictor = new KDTree.Euclidean<>(weights.length);
                takeSquareroot = true;
                break;
            case MANHATTAN:
                predictor = new KDTree.Manhattan<>(weights.length);
                break;
            case SQR_EUCLIDEAN:
                predictor = new KDTree.Euclidean<>(weights.length);
                break;
            default:
                throw new RuntimeException("InexistantDistanceFunctionException");
        }
        MAX_DISTANCE = 0;
        for (int i = 0; i < weights.length; i++) {
            MAX_DISTANCE += weights[i] * weights[i];
        }
        BINS = bins;
        WEIGHTS = weights;
        ALGORITHM = algorithm;
        this.K = k;
    }

    @Override
    public double[] predictBins(double[] data) {
        double[] bins = new double[BINS];
        if (!(predictor.size() == 0)) {
            double[] dataClone = getWeightedData(data.clone());
            int predictionNum = Math.min(ALGORITHM.getK(predictor.size()), predictor.size());
            ArrayList<SearchResult<double[]>> guessFactors = predictor.nearestNeighbours(dataClone, predictionNum);
            ListIterator i = guessFactors.listIterator();
            while (i.hasNext()) {
                SearchResult result = (SearchResult) i.next();
                double[] weightedGuessFactor = (double[]) result.payload;
                int guessFactor = (int) weightedGuessFactor[0];
                double weight = weightedGuessFactor[1];
                double distance = result.distance;
                double finalWeight = weight * MAX_DISTANCE / ((takeSquareroot ? Math.sqrt(distance): distance) + 1) / predictionNum;
                //double finalWeight = weight / ((takeSquare ? distance * distance : distance) + 1);//no Normalisation =(
                bins[guessFactor] += finalWeight;
            }
        }
        return bins;
    }

    @Override
    public void addData(double[] data, int bin, double weight) {
        predictor.addPoint(getWeightedData(data.clone()), new double[]{bin, weight});
    }

    private double[] getWeightedData(double[] data) {
        for (int i = 0; i < data.length; i++) {
            data[i] *= WEIGHTS[i];
        }
        return data;
    }

    public KDeterminationAlgorithm sqrtSize(int maxK, double multiplier) {
        return new SqrtSize(maxK, multiplier);
    }

    public KDeterminationAlgorithm divisionK(int maxK, double divisor) {
        return new DivisionK(maxK, divisor);
    }

    public enum DistanceFunction {
        EUCLIDEAN, MANHATTAN, SQR_EUCLIDEAN
    }

    private abstract class KDeterminationAlgorithm {

        final int MAX_K;

        public KDeterminationAlgorithm(int maxK) {
            MAX_K = maxK;
        }

        public abstract int getK(int size);
    }

    private class SqrtSize extends KDeterminationAlgorithm {

        private final double MULTIPLIER;

        public SqrtSize(int maxK, double multiplier) {
            super(maxK);
            MULTIPLIER = multiplier;
        }

        public int getK(int size) {
            return Math.max(Math.min(K, (int) (Math.sqrt(size) * MULTIPLIER)), 1);
        }
    }

    private class DivisionK extends KDeterminationAlgorithm {

        final double DIVISOR;

        public DivisionK(int maxK, double divisor) {
            super(maxK);
            DIVISOR = divisor;
        }

        public int getK(int size) {
            return Math.max(Math.min(K, (int) (size / DIVISOR)), 1);
        }
    }
}
